#!/bin/bash
set -u

# Usage: 
# bootstrap-linux.sh [<SDPBranch> [<HelixInstallerBranch>]]
# The <SDPBranch> parameter (must be first argument) and
# <HelixInstallerBranch> parameter (must be second argument)
# are optional.  SDPBranch determines the branch of the
# SDP to test with, 'main' by default but can be 'dev'.  The
# HelixInstallerBranch is auto-detected based on the current
# directory if possible, otherwise 'dev' by default, but can
# be 'main'.

# Bootstraps a new Linux server with requirements Helix Installer testing.

function msg () { echo -e "$*"; }
function bail () { msg "\\nError: ${1:-Unknown Error}\\n"; exit "${2:-1}"; }

declare Version=1.0.3
declare SDPBranch=${1:-main}
declare HelixInstallerBranch=${2:-UNSET}

msg "Starting ${0##*/} v$Version at $(date)."

if [[ "$HelixInstallerBranch" == "UNSET" ]]; then
   if [[ "$PWD" == *"/dev/"* ]]; then
      HelixInstallerBranch="dev"
   elif [[ "$PWD" == *"/main/"* ]]; then
      HelixInstallerBranch="main"
   else
      HelixInstallerBranch="dev"
      msg "Helix Installer defaulted to '$HelixInstallerBranch'."
   fi
fi

# Currently, RHEL/CentOS and Ubuntu flavors are supported.
# See release notes for more specific details of which versions are
# currently supported.
if [[ -r "/etc/redhat-release" ]]; then
   msg "Verified: Running Red Hat or similar Linux OS."
elif [[ -r "/etc/lsb-release" ]]; then
   msg "Verified: Running Ubuntu or similar Linux OS."
else
   msg "Warning: Running on unknown OS. Hoping for the best."
fi

sudo mkdir -p /hxdepots/reset
cd /hxdepots/reset || bail "Failed to do 'cd /hxdepots/reset'. Aborting."
curl -k -s -O https://swarm.workshop.perforce.com/downloads/guest/perforce_software/helix-installer/$HelixInstallerBranch/src/reset_sdp.sh

sudo chmod +x reset_sdp.sh

HelixInstallerVersion=$(grep '^Version=' reset_sdp.sh)
HelixInstallerVersion=${HelixInstallerVersion#declare }
msg "Installer Installer version: $HelixInstallerVersion"

HelixInstallerCmd="./reset_sdp.sh -b $SDPBranch"
msg "Calling Helix Installer: $HelixInstallerCmd"
#shellcheck disable=SC2086,SC2024
sudo $HelixInstallerCmd > reset_sdp.log 2>&1
